@@ -17,6 +17,6 @@ FilterListByDialog::~FilterListByDialog()
 
 void FilterListByDialog::on_okButton_clicked()
 {
-    emit choicePicked(this->type, ui->comboBox->currentText());
+    emit choicePicked(this->type, ui->comboBox->currentText(), ui->orderByComboBox->currentIndex());
     close();
 }
