@@ -25,7 +25,7 @@ private:
     int type;
 
 signals:
-    void choicePicked(int type, QString filter);
+    void choicePicked(int type, QString filter, int sortType);
 
 private slots:
     void on_okButton_clicked();
