@@ -9,7 +9,22 @@
         <translation>Filtra la lista per</translation>
     </message>
     <message>
-        <location filename="filterlistbydialog.ui" line="42"/>
+        <location filename="filterlistbydialog.ui" line="31"/>
+        <source>OrderByName</source>
+        <translation>Ordina per nome</translation>
+    </message>
+    <message>
+        <location filename="filterlistbydialog.ui" line="36"/>
+        <source>OrderByGenre</source>
+        <translation>Ordina per genere</translation>
+    </message>
+    <message>
+        <location filename="filterlistbydialog.ui" line="41"/>
+        <source>OrderByCountry</source>
+        <translation>Ordina per paese</translation>
+    </message>
+    <message>
+        <location filename="filterlistbydialog.ui" line="61"/>
         <source>Ok</source>
         <translation></translation>
     </message>
@@ -120,88 +135,138 @@ p, li { white-space: pre-wrap; }
         <translation>Menu</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="589"/>
-        <location filename="mainwindow.cpp" line="263"/>
+        <location filename="mainwindow.ui" line="590"/>
+        <location filename="mainwindow.cpp" line="270"/>
         <source>About</source>
         <translation>Informazioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="594"/>
+        <location filename="mainwindow.ui" line="595"/>
         <source>About Qt</source>
         <translation>Informazioni su Qt</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="599"/>
+        <location filename="mainwindow.ui" line="600"/>
         <source>ToggleFullscreen</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="602"/>
+        <location filename="mainwindow.ui" line="603"/>
         <source>Ctrl+F</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="610"/>
+        <location filename="mainwindow.ui" line="611"/>
         <source>ClearList</source>
         <translation>Azzera Lista</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="615"/>
+        <location filename="mainwindow.ui" line="616"/>
         <source>RestoreDefaultList</source>
         <translation>Ripristina Lista di default</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="620"/>
+        <location filename="mainwindow.ui" line="621"/>
         <source>FilterListByGenre</source>
         <translation>Filtra lista per genere</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="625"/>
+        <location filename="mainwindow.ui" line="626"/>
         <source>FilterListByCountry</source>
         <translation>Filtra lista per paese</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="630"/>
+        <location filename="mainwindow.ui" line="631"/>
+        <source>OrderByName</source>
+        <translation>Ordina per nome</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="641"/>
+        <source>Quit</source>
+        <translation>Esci</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="644"/>
+        <source>Ctrl+Q</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="652"/>
+        <source>OrderByGenre</source>
+        <translation>Ordina per genere</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="657"/>
+        <source>OrderByCountry</source>
+        <translation>Ordina per paese</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="662"/>
+        <source>AddToFavourites</source>
+        <translation>Aggiungi ai preferiti</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="665"/>
+        <source>Ctrl+A</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="670"/>
+        <source>DeleteFromFavourites</source>
+        <translation>Rimuovi dai preferiti</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="673"/>
+        <source>Ctrl+D</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="678"/>
+        <source>GetFavouriteList</source>
+        <translation>Lista preferiti</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="446"/>
         <source>DoNotFilter</source>
         <translation>Nessun filtro</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="635"/>
+        <location filename="mainwindow.ui" line="636"/>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="84"/>
+        <location filename="mainwindow.cpp" line="87"/>
         <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="107"/>
+        <location filename="mainwindow.cpp" line="113"/>
         <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="115"/>
+        <location filename="mainwindow.cpp" line="121"/>
         <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="123"/>
+        <location filename="mainwindow.cpp" line="129"/>
         <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="131"/>
+        <location filename="mainwindow.cpp" line="137"/>
         <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="187"/>
         <source>No lyric found</source>
         <translation>Nessun testo trovato</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="200"/>
+        <location filename="mainwindow.cpp" line="206"/>
         <source>Loading lyrics...</source>
         <translation>Sto cercando il testo...</translation>
     </message>
@@ -215,69 +280,79 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt; {2&gt;?} {0.0.8&lt;?} {2&gt;?} {88@?} {88@?}</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="264"/>
+        <location filename="mainwindow.cpp" line="271"/>
         <source>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
         <translation>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="275"/>
-        <location filename="mainwindow.cpp" line="277"/>
-        <location filename="mainwindow.cpp" line="279"/>
-        <location filename="mainwindow.cpp" line="281"/>
+        <location filename="mainwindow.cpp" line="282"/>
+        <location filename="mainwindow.cpp" line="284"/>
+        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="288"/>
         <source>New Station</source>
         <translation>Nuova stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="275"/>
-        <location filename="mainwindow.cpp" line="303"/>
+        <location filename="mainwindow.cpp" line="282"/>
+        <location filename="mainwindow.cpp" line="310"/>
         <source>Insert Name: </source>
         <translation>Inserisci nome:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="277"/>
-        <location filename="mainwindow.cpp" line="305"/>
+        <location filename="mainwindow.cpp" line="284"/>
+        <location filename="mainwindow.cpp" line="312"/>
         <source>Insert Url: </source>
         <translation>Inserisci Indirizzo:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="279"/>
-        <location filename="mainwindow.cpp" line="307"/>
+        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="314"/>
         <source>Insert Genre: </source>
         <translation>Inserisci Genere:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="281"/>
-        <location filename="mainwindow.cpp" line="309"/>
+        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="316"/>
         <source>Insert Country: </source>
         <translation>Inserisci il Paese:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="303"/>
-        <location filename="mainwindow.cpp" line="305"/>
-        <location filename="mainwindow.cpp" line="307"/>
-        <location filename="mainwindow.cpp" line="309"/>
+        <location filename="mainwindow.cpp" line="310"/>
+        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="314"/>
+        <location filename="mainwindow.cpp" line="316"/>
         <source>Edit Station</source>
         <translation>Modifica la stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="327"/>
-        <location filename="mainwindow.cpp" line="449"/>
-        <location filename="mainwindow.cpp" line="465"/>
+        <location filename="mainwindow.cpp" line="334"/>
+        <location filename="mainwindow.cpp" line="467"/>
+        <location filename="mainwindow.cpp" line="483"/>
         <source>Internet Radio Widget</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="328"/>
+        <location filename="mainwindow.cpp" line="335"/>
         <source>Do you really want to delete the chosen station?</source>
         <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="450"/>
+        <location filename="mainwindow.cpp" line="447"/>
+        <source>FilterList</source>
+        <translation>Filtra lista</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="448"/>
+        <source>ManageFavourites</source>
+        <translation>Gestisci preferiti</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="468"/>
         <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
         <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="466"/>
+        <location filename="mainwindow.cpp" line="484"/>
         <source>This will clear your stations list and restore default one.&lt;p&gt;Do you really want to continue?</source>
         <translation>Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
     </message>
@@ -295,9 +370,20 @@ p, li { white-space: pre-wrap; }
         <translation>Icona App</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="174"/>
+        <location filename="settingsdialog.ui" line="144"/>
+        <source>Hide when closing</source>
+        <translation>Nascondi invece di uscire</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="187"/>
         <source>Save</source>
         <translation>Salva</translation>
     </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="34"/>
+        <location filename="settingsdialog.cpp" line="41"/>
+        <source>Icon changed</source>
+        <translation>Icona modificata</translation>
+    </message>
 </context>
 </TS>
