@@ -35,17 +35,21 @@ namespace Ui {
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "it.ggiovanni.internetradioplayer")
 
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+public slots:
+    Q_SCRIPTABLE int top_application();
+
 private slots:
     void on_playButton_clicked();
     void getMetaData();
     void imageLoaded(int requestId, bool);
     void onRequestFinished(QNetworkReply *reply);
-    void filterList(int type, QString filter);
+    void filterList(int type, QString filter, int orderBy);
     void on_playingNowButton_clicked();
     void on_lyricsButton_clicked();
     void on_stationsButton_clicked();
@@ -65,13 +69,18 @@ private slots:
     void on_actionRestoreDefaultList_triggered();
     void on_artistLineEdit_returnPressed();
     void on_titleLineEdit_returnPressed();
-    void on_actionFilterListByGenre_triggered();
     void on_actionFilterListByCountry_triggered();
-    void on_actionDoNotFilter_triggered();
     void toggleButtonPressed();
     void on_lyricsWebViewButton_clicked();
-
     void on_actionSettings_triggered();
+    void on_actionQuit_triggered();
+    void on_actionDoNotFilterOrderByName_triggered();
+    void on_actionDoNotFilterOrderByGenre_triggered();
+    void on_actionDoNotFilterOrderByCountry_triggered();
+    void on_actionFilterListByGenre_triggered();
+    void on_actionDeleteFromFavourites_triggered();
+    void on_actionGetFavouriteList_triggered();
+    void on_actionAddToFavourites_triggered();
 
 private:
     Ui::MainWindow *ui;
@@ -80,6 +89,9 @@ private:
     QLabel labelBox;
     QStringList stationsList;
 
+    bool hideWhenClosing;
+    bool quitActionPressed;
+
     StationsDB stationsDb;
     BluetoothHeadsetAdapter bluetoothAdapter;
 
@@ -101,6 +113,8 @@ private:
     void saveStationsList();
     void connectBluetoothControl();
 
+    void closeEvent(QCloseEvent *event);
+
 
 };
 
