@@ -3,6 +3,10 @@
 
 #include <QDialog>
 
+#include <QtMaemo5>
+#include <QtCore>
+#include <QtGui>
+
 namespace Ui {
     class SettingsDialog;
 }
@@ -17,13 +21,21 @@ public:
 
 private slots:
     void on_icon2Button_clicked();
-
     void on_icon1Button_clicked();
 
+    void on_pushButton_clicked();
+
 private:
     Ui::SettingsDialog *ui;
 
+    QMaemo5InformationBox infoBox;
+    QLabel labelBox;
+
+    bool hideWhenClosing;
+
     void setIcons();
+    void readSettings();
+    void saveSettings();
 };
 
 #endif // SETTINGSDIALOG_H
