@@ -5,11 +5,18 @@ StationsDB::StationsDB()
 
 }
 
-QStringList StationsDB::getFullStationList()
+QStringList StationsDB::getFullStationList(OrderBy orderBy)
 {
 
     QSqlQuery query( db );
-    query.exec("SELECT name, url, country, genre FROM stations ORDER BY name");
+    switch ( orderBy )
+    {
+        case OrderByName: query.exec("SELECT name, url, country, genre FROM stations ORDER BY name"); break;
+        case OrderByGenre: query.exec("SELECT name, url, country, genre FROM stations ORDER BY genre ASC, name ASC"); break;
+        case OrderByCountry: query.exec("SELECT name, url, country, genre FROM stations ORDER BY country ASC, name ASC"); break;
+    }
+
+
 
     QStringList stationsList;
     while (query.next())
@@ -104,10 +111,16 @@ QStringList StationsDB::getCountryList()
     return countryList;
 }
 
-QStringList StationsDB::getListFilteredByGenre(QString filter)
+QStringList StationsDB::getListFilteredByGenre(QString filter, OrderBy orderBy)
 {
     QSqlQuery query( db );
-    query.exec(QString("SELECT name, url, country, genre FROM stations WHERE genre='%1' ORDER BY name").arg(filter));
+    switch ( orderBy )
+    {
+        case OrderByName: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE genre='%1' ORDER BY name").arg(filter)); break;
+        case OrderByGenre: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE genre='%1' ORDER BY genre").arg(filter)); break;
+        case OrderByCountry: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE genre='%1' ORDER BY country").arg(filter)); break;
+    }
+
 
     QStringList stationsList;
     while (query.next())
@@ -124,10 +137,16 @@ QStringList StationsDB::getListFilteredByGenre(QString filter)
     return stationsList;
 }
 
-QStringList StationsDB::getListFilteredByCountry(QString filter)
+QStringList StationsDB::getListFilteredByCountry(QString filter, OrderBy orderBy)
 {
     QSqlQuery query( db );
-    query.exec(QString("SELECT name, url, country, genre FROM stations WHERE country='%1' ORDER BY name").arg(filter));
+    switch ( orderBy )
+    {
+        case OrderByName: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE country='%1' ORDER BY name").arg(filter)); break;
+        case OrderByGenre: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE country='%1' ORDER BY genre").arg(filter)); break;
+        case OrderByCountry: query.exec(QString("SELECT name, url, country, genre FROM stations WHERE country='%1' ORDER BY country").arg(filter)); break;
+    }
+
 
     QStringList stationsList;
     while (query.next())
@@ -167,4 +186,43 @@ void StationsDB::updateStation(QString currentUrl, QString name, QString url, QS
     qDebug()<<query.lastError();
 }
 
+void StationsDB::setFavourite(QString url, bool choice)
+{
+    if ( choice )
+    {
+        QSqlQuery query( db );
+        qDebug()<<query.exec( QString("UPDATE stations SET favourite=1 WHERE url='%1'").arg(url) );
+        qDebug()<<query.lastError();
+    }
+    else
+    {
+        QSqlQuery query( db );
+        qDebug()<<query.exec( QString("UPDATE stations SET favourite=0 WHERE url='%1'").arg(url) );
+        qDebug()<<query.lastError();
+    }
+}
+
+QStringList StationsDB::getFavouriteList()
+{
+    QSqlQuery query( db );
+
+    query.exec(QString("SELECT name, url, country, genre FROM stations WHERE favourite=1 ORDER BY name"));
+
+
+
+    QStringList stationsList;
+    while (query.next())
+    {
+             QString name = query.value(0).toString();
+             QString url = query.value(1).toString();
+             QString country = query.value(2).toString();
+             QString genre = query.value(3).toString();
+
+             stationsList<<QString("%1 [%2] [%3]--%4").arg(name).arg(country).arg(genre).arg(url);
+    }
+
+
+    return stationsList;
+}
+
 
